
#include <stdlib.mqh>
#include <stderror.mqh>

// This is where you set the default values for those input variables.
extern int       EA_MAGIC_NUM = 826542;
extern int       Slippage = 3;
extern double    TakeProfit = 50;
extern double    StopLoss = 250;
extern bool      Add_Spread_To_StopLoss = true;

extern double    Lots = 1.25;

string msg = "";
int CustomSpread = 0;
int PipFactor = 1;
int the_StopLoss = 0;

int init()
{
   if (Digits == 3 || Digits == 5)
   {
      PipFactor = 10;
   }
}

void GetSpread()
{
   // Cater for fractional pips
   if (Digits == 3 || Digits == 5)
   {
      PipFactor = 10;
   }
   
   CustomSpread = (MarketInfo(Symbol(),MODE_SPREAD))  / PipFactor;
   
   // Should we add the spread into the StopLoss?
   the_StopLoss = StopLoss;
   if (StopLoss > 0)
   {
      if (Add_Spread_To_StopLoss)
      {
         the_StopLoss = StopLoss + CustomSpread;
      }
      else
      {
         the_StopLoss = StopLoss;
      }
   }
}

bool SendOrders (int BuyOrSell, double LotSize, double PriceToOpen, double Slippage, double SL_Price, double TP_Price, string comments, datetime ExpirationTime)
{
   int ticket, errorType;
   
   if (BuyOrSell == OP_BUY)
   {  
      Print("Bid: "+Bid+" Ask: "+Ask+" | Opening Buy Order: "+Symbol()+", "+BuyOrSell+", "+LotSize+", "+PriceToOpen+", "+Slippage+", "+SL_Price+", "+TP_Price+", "+comments+", "+ExpirationTime+", Green");
      ticket=OrderSend(Symbol(),BuyOrSell,LotSize,PriceToOpen,Slippage,SL_Price,TP_Price,comments,EA_MAGIC_NUM,ExpirationTime,Green);
      if(ticket>0)
      {
         if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) 
         {
            Print("BUY order opened : ",OrderOpenPrice());
            msg = ticket + ": Buy position opened on "+Symbol()+" at "+ Day()+"/"+Month()+"/"+Year()+" - "+Hour()+":"+Minute()+":"+Seconds();
            Print(msg);
            return (true);
         }
      }
      else 
      {  
         errorType = GetLastError();
         Print("Error opening BUY order : ", ErrorDescription(errorType));
         msg = "CANNOT open BUY position on "+Symbol()+" at "+ Day()+"/"+Month()+"/"+Year()+" - "+Hour()+":"+Minute()+":"+Seconds();
         Print(msg);
         return (false);
      }
   }
   if (BuyOrSell == OP_SELL)
   {  
      Print("Bid: "+Bid+" Ask: "+Ask+" | Opening Sell Order: "+Symbol()+", "+BuyOrSell+", "+LotSize+", "+PriceToOpen+", "+Slippage+", "+SL_Price+", "+TP_Price+", "+comments+", "+ExpirationTime+", Red");
      ticket=OrderSend(Symbol(),BuyOrSell,LotSize,PriceToOpen,Slippage,SL_Price,TP_Price,comments,EA_MAGIC_NUM,ExpirationTime,Red);
      if(ticket>0)
      {
         if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) 
         {
            Print("Sell order opened : ",OrderOpenPrice());
            msg = ticket + ": Sell position opened on "+Symbol()+" at "+ Day()+"/"+Month()+"/"+Year()+" - "+Hour()+":"+Minute()+":"+Seconds();
            Print(msg);
            return (true);
         }
      }
      else 
      {  
         errorType = GetLastError();
         Print("Error opening SELL order : ", ErrorDescription(errorType));
         msg = "CANNOT open SELL position on "+Symbol()+" at "+ Day()+"/"+Month()+"/"+Year()+" - "+Hour()+":"+Minute()+":"+Seconds();
         Print(msg);
         return (false);
      }
   }
}

bool DecideToOpenTrade()
{
   int total = OrdersTotal();
   if (total > 1)
   {
      for(int cnt=0;cnt<total;cnt++)
      {
         if(OrderSelect(cnt,SELECT_BY_POS))
         {
            if(OrderSymbol()==Symbol() && OrderMagicNumber() == EA_MAGIC_NUM)
            {
               return (false);
            }
         }
      }
   }
   return (true);
}

//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
{
//----
   if (!DecideToOpenTrade())
   {
      return (0);
   }
   GetSpread();
   double PriceToOpen;
   double TakeProfitPrice;
   double StopLossPrice;
  
   // Open Buy  
   PriceToOpen = Ask;
   if (TakeProfit == 0)
   {
      TakeProfitPrice = 0;
   }
   else
   {
      TakeProfitPrice = PriceToOpen + (TakeProfit * Point * PipFactor);
      TakeProfitPrice = NormalizeDouble(TakeProfitPrice,Digits);
   }
   
   if (the_StopLoss == 0)
   {
      StopLossPrice = 0;
   }
   else
   {
      StopLossPrice = PriceToOpen - (the_StopLoss * Point * PipFactor);
      StopLossPrice = NormalizeDouble(StopLossPrice,Digits);
   }
   SendOrders(OP_BUY, Lots, PriceToOpen, Slippage, StopLossPrice, TakeProfitPrice, "", 0);
   // -----------------------------------------------------------------------------------------
   // Open Sell
   PriceToOpen = Bid;
   if (TakeProfit == 0)
   {
      TakeProfitPrice = 0;
   }
   else
   {
      TakeProfitPrice = PriceToOpen - (TakeProfit * Point * PipFactor);
      TakeProfitPrice = NormalizeDouble(TakeProfitPrice,Digits);
   }
   if (the_StopLoss == 0)
   {
      StopLossPrice = 0;
   }
   else
   {
      StopLossPrice = PriceToOpen + (the_StopLoss * Point * PipFactor);
      StopLossPrice = NormalizeDouble(StopLossPrice,Digits);
   }
   SendOrders(OP_SELL, Lots, PriceToOpen, Slippage, StopLossPrice, TakeProfitPrice, "", 0);
//----
//----
   return(0);
}
//+------------------------------------------------------------------+